from __future__ import unicode_literals

from django.contrib.auth.models import (AbstractBaseUser, BaseUserManager,
                                        PermissionsMixin)
from django.core.mail import send_mail
from django.db import models
from django.utils import six, timezone
from django.utils.translation import ugettext_lazy as _

from mobile_auth.fields import EmailNullField, PhoneNumberNullField
from mobile_auth.validators import (ASCIIUsernameValidator,
                                    UnicodeUsernameValidator)


class MobileUserManager(BaseUserManager):
    use_in_migrations = True

    def _create_user(self, username, email, password, phone_number, **extra_fields):
        """Creates and saves a User with the given username, email and password."""
        if not username:
            raise ValueError('The given username must be set')
        email = self.normalize_email(email)
        phone_number = phone_number
        username = self.model.normalize_username(username)
        user = self.model(username=username, email=email, phone_number=phone_number, **extra_fields)
        user.set_password(password)
        user.save(using=self._db)
        return user

    def create_user(self, username, email=None, phone_number=None, password=None, **extra_fields):
        extra_fields.setdefault('is_staff', False)
        extra_fields.setdefault('is_superuser', False)
        return self._create_user(username, email, password, phone_number=phone_number, **extra_fields)

    def create_superuser(self, username, password, email=None, phone_number=None, **extra_fields):
        extra_fields.setdefault('is_staff', True)
        extra_fields.setdefault('is_superuser', True)

        if extra_fields.get('is_staff') is not True:
            raise ValueError('Superuser must have is_staff=True.')
        if extra_fields.get('is_superuser') is not True:
            raise ValueError('Superuser must have is_superuser=True.')

        return self._create_user(username, email, password, phone_number=phone_number, **extra_fields)


class AbstractMobileUser(AbstractBaseUser, PermissionsMixin):
    """
    An abstract base class implementing a fully featured User model with admin-compliant permissions.

    Username and password are required. Other fields are optional.
    """

    username_validator = UnicodeUsernameValidator() if six.PY3 else ASCIIUsernameValidator()
    username = models.CharField(
        _('username'),
        max_length=50,
        unique=True,
        help_text=_('Required. 50 characters or fewer. Letters, digits and ./-/_ only.'),
        validators=[username_validator],
        error_messages={
            'unique': _("A user with that username already exists."),
        },
    )
    first_name = models.CharField(_('first name'), max_length=30, blank=True)
    last_name = models.CharField(_('last name'), max_length=150, blank=True)
    email = EmailNullField(_('email address'), max_length=255, blank=True, null=True, unique=True)
    phone_number = PhoneNumberNullField(_('phone number'), blank=True, null=True, unique=True)
    is_staff = models.BooleanField(
        _('staff status'),
        default=False,
        help_text=_('Designates whether the user can log into this admin site.'),
    )
    is_active = models.BooleanField(
        _('active'),
        default=True,
        help_text=_(
            'Designates whether this user should be treated as active. '
            'Unselect this instead of deleting accounts.'
        ),
    )
    date_joined = models.DateTimeField(_('date joined'), default=timezone.now)

    objects = MobileUserManager()

    USERNAME_FIELD = 'username'  # It should be ['username', 'email', 'phone_number']
    # REQUIRED_FIELDS = []

    class Meta:
        verbose_name = _('user')
        verbose_name_plural = _('users')
        abstract = True

    def get_full_name(self):
        """Return the first_name plus the last_name, with a space in between."""
        full_name = '%s %s' % (self.first_name, self.last_name)
        return full_name.strip()

    def get_short_name(self):
        """Return the short name for the user."""
        return self.first_name

    def email_user(self, subject, message, from_email=None, **kwargs):
        """Sends an email to this User."""
        send_mail(subject, message, from_email, [self.email], **kwargs)


class MobileUser(AbstractMobileUser):

    class Meta(AbstractMobileUser.Meta):
        swappable = 'AUTH_USER_MODEL'
